@@ -382,7 +382,7 @@ def interceptor_sock_connect(fn, *args, **kwargs):
         ctx.socket_connecting = False
 
 
-def interceptor_db_con(fn, db_type, *args, **kwargs):
+def interceptor_db_con(fn, db_info, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
     if not ctx:
         return fn(*args, **kwargs)
@@ -399,7 +399,8 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     if not kwargs:
         kwargs = dict(
             x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
-    text = '{}://'.format(db_type)
+
+    text = '{}://'.format(db_info.get('type'))
     text += kwargs.get('user')
     text += "@"
     text += kwargs.get('host', kwargs.get('dsn', ''))
@@ -441,7 +442,7 @@ def addQuoteList(arg_list):
     return tuple(quoted_list)
 
 
-def interceptor_db_execute(fn, *args, **kwargs):
+def interceptor_db_execute(fn, db_info, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
     # sendDebugProfile(ctx, 'interceptor_db_execute step -1')
     self = args[0]
@@ -465,6 +466,24 @@ def interceptor_db_execute(fn, *args, **kwargs):
     if not query:
         return fn(*args, **kwargs)
 
+    start_time = DateUtil.nowSystem()
+    ctx.start_time = start_time
+
+    text = '{}://'.format(db_info.get('type'))
+    text += db_info.get('user')
+    text += "@"
+    text += db_info.get('host', db_info.get('dsn', ''))
+    text += '/'
+    text += db_info.get('database', db_info.get('db', db_info.get('dbname', '')))
+    ctx.active_dbc = text
+    ctx.lctx['dbc'] = text
+
+    ctx.active_dbc = 0
+
+    datas = [text]
+    ctx.elapsed = DateUtil.nowSystem() - start_time
+    async_sender.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
+
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
     ctx.active_sqlhash = query
